@@ -20,8 +20,8 @@ class GoogleOAuth2LoginHandler(Route, GoogleOAuth2Mixin):
 
     @coroutine
     def get(self):
-        referer = self.request.headers.get('Referer', '/')
         if self.application.settings.get('debug', False):
+            referer = self.request.headers.get('Referer', '/')
             self.set_secure_cookie('user', json_encode('debug'))
             self.set_flash_message('success', 'Debug login successful')
             return self.redirect(referer)
@@ -39,7 +39,7 @@ class GoogleOAuth2LoginHandler(Route, GoogleOAuth2Mixin):
             if not self.settings['google_oauth'].get('domain', ''):
                 self.set_secure_cookie('user', json_encode(user))
                 self.set_flash_message('success', 'Login successful')
-                return self.redirect(referer)
+                return self.redirect('/')
 
             access_token = str(user['access_token'])
             response = yield AsyncHTTPClient().fetch(
@@ -57,15 +57,15 @@ class GoogleOAuth2LoginHandler(Route, GoogleOAuth2Mixin):
             email = body['email']
             if not email.endswith(
                     '@%s' % self.settings['google_oauth']['domain']):
-                self.set_flash_message('danger', '%s is not inlol domain %s' % (
-                    email, self.settings['google_oauth']['domain']
-                ))
+                self.set_flash_message(
+                    'danger', '%s is not in domain %s' % (
+                        email, self.settings['google_oauth']['domain']))
                 raise HTTPError(403)
 
             self.set_secure_cookie('user', email, expires_days=1)
             self.set_flash_message(
                 'success', 'Login successful for %s' % email)
-            return self.redirect(referer)
+            return self.redirect('/')
 
         yield self.authorize_redirect(
             redirect_uri=self.oauth_url,
